@@ -368,20 +368,32 @@ class SetupReproEnv(Subcommand):
         urls = {}
         actual_version_id = None
 
-        # Assuming that project names contain <major>.<minor> version
-        evg_project = f"mongodb-mongo-v{version}"
-        if version == "master":
-            evg_project = "mongodb-mongo-master"
+        def get_version(project_name, api):
+            all_versions = evergreen_conn.get_evergreen_versions(api, project_name)
+            found_version = None
+            try:
+                found_version = next(all_versions)
+            except HTTPError as err:
+                if err.response.status_code != 404:
+                    raise
+            except StopIteration:
+                pass
+            return found_version, all_versions
 
-        evg_versions = evergreen_conn.get_evergreen_versions(self.evg_api, evg_project)
-        evg_version = None
-        try:
-            evg_version = next(evg_versions)
-        except HTTPError as err:
-            if err.response.status_code != 404:
-                raise
-        except StopIteration:
-            return EvgURLInfo()
+        if version == "master":
+            # For the master branch, check the new -nightly project, if the desired version
+            # is not found, fall back to the old mongodb-mongo-master project.
+            evg_project = "mongodb-mongo-master-nightly"
+            evg_version, evg_versions = get_version(evg_project, self.evg_api)
+            if evg_version is None:
+                evg_project = "mongodb-mongo-master"
+                evg_version, evg_versions = get_version(evg_project, self.evg_api)
+                if evg_version is None:
+                    return EvgURLInfo()
+        else:
+            # Assuming that project names contain <major>.<minor> version
+            evg_project = f"mongodb-mongo-v{version}"
+            evg_version, evg_versions = get_version(evg_project, self.evg_api)
 
         buildvariant_name = self.get_buildvariant_name(version)
         LOGGER.debug("Found buildvariant.", buildvariant_name=buildvariant_name)
